@@ -36,8 +36,10 @@ typedef struct {
 	GObjectClass parent_class;
 } CouchDBClass;
 
-GType    couchdb_get_type (void);
-CouchDB *couchdb_new (const char *hostname);
+GType       couchdb_get_type (void);
+CouchDB    *couchdb_new (const char *hostname);
+
+const char *couchdb_get_hostname (CouchDB *couchdb);
 
 /*
  * Databases API
@@ -76,11 +78,16 @@ CouchDBDocument *couchdb_document_get (CouchDB *couchdb,
 				       const char *dbname,
 				       const char *docid,
 				       GError **error);
-gboolean         couchdb_document_put (CouchDBDocument *document, GError **error);
+gboolean         couchdb_document_put (CouchDBDocument *document,
+				       const char *dbname,
+				       GError **error);
+gboolean         couchdb_document_delete (CouchDBDocument *document, GError **error);
+
 const char      *couchdb_document_get_id (CouchDBDocument *document);
 void             couchdb_document_set_id (CouchDBDocument *document, const char *id);
 
 const char      *couchdb_document_get_revision (CouchDBDocument *document);
+void             couchdb_document_set_revision (CouchDBDocument *document, const char *revision);
 
 gboolean         couchdb_document_is_contact (CouchDBDocument *document);
 
